@@ -29,3 +29,14 @@ class FinancePayMode(generics.UpdateAPIView):  # 或继承(APIView)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
+
+        # 支付方式修改
+
+    def put(self, request, *args, **kwargs):
+        params = parse_data(request)
+        if not params:
+            return util_response(err=6046, msg='至少需要一个请求参数')
+        data, err_txt = FinancePayModeService.put(params=params)
+        if err_txt is None:
+            return util_response(data=data)
+        return util_response(err=47767, msg=err_txt)
