@@ -192,6 +192,15 @@ class FinanceService:
                 return {'err': 3003, 'msg': 'pay_mode不存在', }
             query_dict['pay_mode__pay_mode'] = pay_mode
 
+        sand_box_list = params.get('sand_box_list', '')
+        if sand_box_list:
+            # print(">>> sand_box_list:", type(sand_box_list), sand_box_list)
+            sand_box_list = sand_box_list.split(',')
+            sand_box_set = SandBox.objects.filter(Q(sand_box_name__in=sand_box_list)).first()
+            if not sand_box_set:
+                return {'err': 3004, 'msg': 'sand_box不存在', }
+            query_dict['sand_box__sand_box_name__in'] = sand_box_list
+
         # 搜索沙盒
         sand_box = params.get('sand_box', '')
         # 如果沙盒为空则搜索全部内容，但沙盒为假值或者0时，则只显示非沙盒
