@@ -1,3 +1,5 @@
+import sys
+from pathlib import Path
 from decimal import Decimal
 import math
 import random
@@ -8,12 +10,23 @@ from django.utils import timezone
 from django.utils.datetime_safe import datetime
 import pytz
 from rest_framework import serializers
-
+from main.settings import BASE_DIR
 from xj_user.models import BaseInfo
 from xj_user.services.user_platform_service import UserPlatformService
 from .finance_service import FinanceService
 from ..models import Transact, Currency, PayMode, SandBox
 from ..utils.jt import Jt
+from ..utils.j_config import JConfig
+from ..utils.j_dict import JDict
+
+module_root = str(Path(__file__).resolve().parent)
+# 配置之对象
+main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
+module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
+
+# 商户名称
+merchant_name = main_config_dict.merchant_name or module_config_dict.merchant_name or ""
+sub_appid = main_config_dict.wechat_merchant_app_id or module_config_dict.wechat_merchant_app_id or ""
 
 
 # 声明用户序列化
@@ -84,7 +97,8 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
             'goods_info',
             'pay_info',
             'finance_status_code',
-            'sand_box_status_code'
+            'sand_box_status_code',
+            'snapshot'
         ]
 
     def get_lend(self, obj):
@@ -151,7 +165,6 @@ class FinanceTransactService:
 
         # POST方法，如果无transact_no则是新增，否则为修改
 
-
     @staticmethod
     def finance_transact_detailed(transact_no):
         transact = Transact.objects.filter(transact_no=transact_no).first()
@@ -173,20 +186,21 @@ class FinanceTransactService:
         #     return Response({'err': 4002, 'msg': 'token验证失败', })
 
         # ========== 二、必填性检查 ==========
-        if not param.get('platform', '') and not param.get('platform_id', ''):
-            return None, '缺少platform'
+        # if not param.get('platform', '') and not param.get('platform_id', ''):
+        #     return None, '缺少platform'
         if not param.get('amount', '') and not param.get('income', '') and not param.get('outgo', ''):
             return None, '缺少amount'
         if not param.get('currency', '') and not param.get('currency_id', ''):
             return None, '缺少currency'
         if not param.get('pay_mode', '') and not param.get('pay_mode_id', ''):
             return None, '缺少pay_mode'
-        if not param.get('summary', ''):
-            return None, '缺少summary'
+        # if not param.get('summary', ''):
+        #     return None, '缺少summary'
         # ========== 三、内容的类型准确性检查 ==========
         # 判断无transact_no为新建，否则为修改
         is_create = True
         item['sand_box'] = None
+        item['snapshot'] = None
         transact_has_id = Transact.objects.filter(transact_no=param.get('transact_no', '')).first()
         if transact_has_id:
             res_data = model_to_dict(transact_has_id)
@@ -194,7 +208,6 @@ class FinanceTransactService:
                 return None, '非沙盒数据不允许修改'
             is_create = False
 
-
         # 检查是否有该id
         if not is_create and param.get('id', ''):
             has_id = Transact.objects.filter(id=param.get('id', '')).count() > 0
@@ -203,6 +216,9 @@ class FinanceTransactService:
         # 判断平台是否存在
         if not param.get('platform_id', ''):
             platform_name = param.get('platform', '')
+            if not platform_name:
+                platform_name = merchant_name
+
             platform_info, err = UserPlatformService.get_platform_info(platform_name=platform_name)
             if err:
                 return None, '平台不存在: ' + platform_name
@@ -307,8 +323,7 @@ class FinanceTransactService:
             item['finance_status_code'] = param.get('finance_status_code', '')
 
         if param.get('sand_box_status_code', ""):
-            item['sand_box_status_code'] = param.get('sand_box_status_code',"")
-
+            item['sand_box_status_code'] = param.get('sand_box_status_code', "")
 
         # 沙盒 ----------------------------------------------------------------------
         sand_box_name = param.get('sand_box', '')
@@ -338,6 +353,18 @@ class FinanceTransactService:
         thread_id = param.get('thread_id', '')
         item['thread_id'] = thread_id
 
+        # 快照
+        snapshot = param.get('snapshot', '')
+        if snapshot:
+            item['snapshot'] = snapshot
+            enroll_list = []
+            for i in snapshot['data']:
+                enroll_list.append(i['id'])
+            if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+                from xj_enroll.service.enroll_services import EnrollServices
+            EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
+                                       search_param={"enroll_id_list": enroll_list})
+
         # 如果有沙盒。
         if item['sand_box']:
             balance_set = balance_set.filter(Q(sand_box_id=item['sand_box']))
@@ -361,8 +388,10 @@ class FinanceTransactService:
         item['opposite_account'] = opposite_account
 
         # 摘要
+        item['summary'] = "摘要"
         summary = param.get('summary', '')
-        item['summary'] = summary
+        if summary:
+            item['summary'] = summary
 
         # 商品信息
         goods_info = param.get('goods_info', '')
@@ -398,14 +427,19 @@ class FinanceTransactService:
             # return None, '重复的交易订单号：' + str(order_no)
         # --------------------------------------------------------------------------------------
 
-        if not param.get('their_account_id', '') and not param.get('their_account_name', ''):
+        if param.get('their_account_name', ''):
+            their_account_name = param.get('their_account_name', '')
+        else:
+            their_account_name = sub_appid
+
             # return Response({'err': 1016, 'msg': 'their_account_id或their_account_name 必填', })
-            return None, 'their_account_id或their_account_name 必填'
+            # return None, 'their_account_id或their_account_name 必填'
         # 没有对方账户ID时从对方账户名创建一个账户
         # 如果无their_account_id、有their_account_name，则用their_account_name生成一个their_account_id
-        if not param.get('their_account_id', '') and param.get('their_account_name', ''):
-            their_account_name = param['their_account_name']
+        if not param.get('their_account_id', '') and their_account_name:
+            # their_account_name = param['their_account_name']
             base_info = BaseInfo.objects.filter(nickname=their_account_name).first()
+            # print(their_account_name)
             if base_info:
                 base_info = model_to_dict(base_info)
                 item['their_account_id'] = base_info['id']
@@ -457,6 +491,7 @@ class FinanceTransactService:
         serializer.validated_data['finance_status_code'] = item.get('finance_status_code', None)
         serializer.validated_data['thread_id'] = item.get('thread_id', None)
         serializer.validated_data['sand_box_status_code'] = item.get('sand_box_status_code', None)
+        serializer.validated_data['snapshot'] = item.get('snapshot', None)
 
         # print(">>> serializer.validated_data: ", serializer.validated_data,)
         # print(">>> serializer: ", serializer,)
