@@ -1,4 +1,5 @@
 import json
+import sys
 from decimal import Decimal
 import random
 
@@ -9,8 +10,10 @@ from django.forms import model_to_dict
 from rest_framework import serializers
 from pathlib import Path
 from main.settings import BASE_DIR
+
 from xj_enroll.utils.custom_tool import format_params_handle
 from xj_finance.services.finance_transact_service import FinanceTransactService
+from xj_finance.utils.custom_tool import filter_result_field
 from xj_thread.utils.join_list import JoinList
 from xj_user.models import BaseInfo
 from xj_user.services.user_platform_service import UserPlatformService
@@ -108,7 +111,8 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'is_delete',
             'is_write_off',
             'finance_status_code',
-            "sand_box_status_code"
+            "sand_box_status_code",
+            "snapshot"
         ]
 
     # def get_order(self, obj):
@@ -371,7 +375,6 @@ class FinanceTransactsService:
                     # 生成真实记录成功后 原沙盒记录改为核销 并把提现状态改成 已提现
                 Transact.objects.filter(transact_no=transact_no).update(is_write_off=1, sand_box_status_code="withdrew",
                                                                         is_reverse=None)  # 沙盒核销
-
         return None, None
 
     @staticmethod
@@ -432,7 +435,11 @@ class FinanceTransactsService:
         transact_list, err = FinanceTransactsService.get(params, user_id)
         if err:
             return None, err
-        # print("transact_list", transact_list)
+        transact_list['list'] = filter_result_field(
+            result_list=transact_list['list'],
+            alias_dict={"snapshot": "finance_snapshot"}
+        )
+        print("transact_list", transact_list)
 
         thread_id_list = [item.get("thread_id", None) for item in transact_list['list']]
         # print("thread_id_list:", thread_id_list)
@@ -446,3 +453,28 @@ class FinanceTransactsService:
         # total = transact.count()
         return {'total': 0, 'list': data}, None
         # return {'size': int(size), 'page': int(page + 1), 'total': total, 'list': thread_id_list}, None
+
+    @staticmethod
+    def invoicing_approval(params):
+        finance_id = params.get("finance_id", None)
+        finance = Transact.objects.filter(id=finance_id)
+        finance_data = finance.first()
+        finance_data = model_to_dict(finance_data)
+        snapshot = finance_data['snapshot']
+
+        enroll_list = FinanceTransactsService.get_json_primary_key(snapshot)
+        if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+            from xj_enroll.service.enroll_services import EnrollServices
+        EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoiced"},
+                                   search_param={"enroll_id_list": enroll_list})
+
+        finance.update(sand_box_status_code="Invoiced")  # 沙盒核销
+        # print(enroll_list)
+        return None, None
+
+    @staticmethod
+    def get_json_primary_key(json):
+        enroll_list = []
+        for item in json:
+            enroll_list.append(item['id'])
+        return enroll_list
